@@ -1,7 +1,4 @@
 package MooseX::Meta::Method::Role::Authorized;
-$MooseX::Meta::Method::Role::Authorized::VERSION = '0.00.05';
-use warnings;
-use strict;
 use  MooseX::Meta::Method::Role::Authorized::Meta::Role;
 
 has requires =>
@@ -37,7 +34,7 @@ sub authorized_do {
     my $code = shift;
  
     my ($instance) = @_;
-    foreach my $key (keys(%$requires)){
+    foreach my $key (keys($requires)){
       my $author_sub = '_authorize_'.$key;
       next
         unless ($self->can($author_sub));
@@ -96,23 +93,15 @@ a method.
 This attribute is an hash reference with the values that are going to
 be used by the authorized_do method when checking this invocation.
 
-=back
-
 =head1 METHODS
 
-=over
-
 =item authorized_do
 
-
 Call the Api keys in trun.  If you want to expand on this API simply add in 
 you _sub and validation  like the others
 
-=back
-
 =head1 METHOD
 
-=over
 
 =item wrap
 
